@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae.cpp,v 1.104.2.1 2009/04/08 15:53:24 cvs Exp $
+//      $Id: cae.cpp,v 1.104.2.2 2009/04/27 14:38:09 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -1037,7 +1037,7 @@ void MainObject::DispatchCommand(int ch)
       LogLine(RDConfig::LogInfo,QString().
 	      sprintf("StopPlayback - Card: %d  Stream: %d  Handle: %d",
 		      card,stream,handle));
-      EchoArgs(ch,'+');
+      //      EchoArgs(ch,'+');
       return;
     }
     EchoArgs(ch,'-');
@@ -1791,8 +1791,6 @@ void MainObject::BroadcastCommand(const char *command)
 
 void MainObject::EchoCommand(int ch,const char *command)
 {
-//    LogLine(RDConfig::LogErr,QString().sprintf("EchoCommand(%s)\n",
-//					       (const char *)command));
   if(socket[ch]->state()==QSocket::Connection) {
 #ifdef PRINT_COMMANDS
     printf("CAE: Connection %d sending %s\n",ch,command);
