@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae.h,v 1.69 2007/10/28 20:13:32 fredg Exp $
+//      $Id: cae.h,v 1.70 2008/03/28 20:00:05 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -82,7 +82,7 @@ struct alsa_format {
 //
 // Function Prototypes
 //
-void LogLine(QString line);
+void LogLine(RDConfig::LogPriority prio,const QString &line);
 void SigHandler(int signum);
 extern RDConfig *rd_config;
 
