@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart.h,v 1.34.2.1 2009/03/24 12:11:18 cvs Exp $
+//      $Id: rdcart.h,v 1.34.2.2 2009/11/19 17:56:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -76,6 +76,8 @@ class RDCart
   void setUserDefined(const QString &string) const;
   RDCart::UsageCode usageCode() const;
   void setUsageCode(RDCart::UsageCode code);
+  QString notes() const;
+  void setNotes(const QString &notes) const;
   unsigned forcedLength() const;
   void setForcedLength(unsigned length) const;
   unsigned lengthDeviation() const;
