@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart_dialog.cpp,v 1.40.2.1 2008/11/20 13:02:05 fredg Exp $
+//      $Id: rdcart_dialog.cpp,v 1.40.2.2 2009/11/25 17:19:24 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -518,7 +518,7 @@ void RDCartDialog::RefreshCarts()
 
   cart_cart_list->clear();
   QString group=cart_group_box->currentText();
-  if(group==QString("ALL")) {
+  if(group==QString(tr("ALL"))) {
     group="";
   }
   if(cart_type==RDCart::All) {
