@@ -5,7 +5,7 @@
 //
 //   (C) Copyright 1996-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdconf.cpp,v 1.3 2007/10/05 16:33:31 fredg Exp $
+//    $Id: rdconf.cpp,v 1.5.2.4 2010/02/02 00:30:30 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -31,7 +31,10 @@
 #include <qvariant.h>
 #include <qmessagebox.h>
 #include <qdir.h>
-#ifndef WIN32
+#ifdef WIN32
+#define RDCONF_FILE_SEPARATOR '\\'
+#else
+#define RDCONF_FILE_SEPARATOR '/'
 #include <unistd.h>
 #include <netdb.h>
 #include <sys/timex.h>
@@ -39,7 +42,7 @@
 #endif
 #include <rddb.h>
 #include <rdconf.h>
-
+#include <rdescape_string.h>
 
 #define BUFFER_SIZE 1024
 
@@ -247,7 +250,7 @@ int IncrementIndex(char *sPathname,int dMaxIndex)
   strcat(sLockname,".LCK");
   i=0;
   while(dLockname<0 && i<MAX_RETRIES) {
-    dLockname=open(sLockname,O_WRONLY|O_EXCL|O_CREAT|S_IRUSR|S_IWUSR);
+      dLockname=open(sLockname,O_WRONLY|O_EXCL|O_CREAT,S_IRUSR|S_IWUSR);
     i++;
   }
   if(dLockname<0) {
@@ -362,7 +365,8 @@ QString RDGetPathPart(QString path)
 {
   int c;
 
-  c=path.findRev('/');
+  //  c=path.findRev('/');
+  c=path.findRev(RDCONF_FILE_SEPARATOR);
   if(c<0) {
     return QString("");
   }
@@ -375,7 +379,8 @@ QString RDGetBasePart(QString path)
 {
   int c;
 
-  c=path.findRev('/');
+  //  c=path.findRev('/');
+  c=path.findRev(RDCONF_FILE_SEPARATOR);
   if(c<0) {
     return path;
   }
@@ -435,9 +440,12 @@ QFont::Weight RDGetFontWeight(QString string)
 
 
 #ifndef WIN32
-bool RDDetach()
+bool RDDetach(const QString &coredir)
 {
-  if(daemon(0,0)) {
+  if(!coredir.isEmpty()) {
+    chdir(coredir);
+  }
+  if(daemon(coredir.isEmpty(),0)) {
     return false;
   }
   return true;
@@ -517,18 +525,19 @@ QString RDGetDisplay(bool strip_point)
 }
 
 
-bool RDDoesRowExist(QString table,QString name,QString test,QSqlDatabase *db)
+bool RDDoesRowExist(const QString &table,const QString &name,
+		    const QString &test,QSqlDatabase *db)
 {
   RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("SELECT %s FROM %s WHERE %s=\"%s\"",
-			(const char *)name,
-			(const char *)table,
-			(const char *)name,
-			(const char *)test);
+			(const char *)RDEscapeStringSQLColumn(name),
+			(const char *)RDEscapeStringSQLColumn(table),
+			(const char *)RDEscapeStringSQLColumn(name),
+			(const char *)RDEscapeString(test));
   q=new RDSqlQuery(sql,db);
-  if(q->size()>0) {
+  if(q->first()) {
     delete q;
     return true;
   }
@@ -537,15 +546,16 @@ bool RDDoesRowExist(QString table,QString name,QString test,QSqlDatabase *db)
 }
 
 
-bool RDDoesRowExist(QString table,QString name,unsigned test,QSqlDatabase *db)
+bool RDDoesRowExist(const QString &table,const QString &name,unsigned test,
+		    QSqlDatabase *db)
 {
   RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("SELECT %s FROM %s WHERE %s=%d",
-			(const char *)name,
-			(const char *)table,
-			(const char *)name,
+			(const char *)RDEscapeStringSQLColumn(name),
+			(const char *)RDEscapeStringSQLColumn(table),
+			(const char *)RDEscapeStringSQLColumn(name),
 			test);
   q=new RDSqlQuery(sql,db);
   if(q->size()>0) {
@@ -557,18 +567,19 @@ bool RDDoesRowExist(QString table,QString name,unsigned test,QSqlDatabase *db)
 }
 
 
-QVariant RDGetSqlValue(QString table,QString name,QString test,
-		      QString param,QSqlDatabase *db,bool *valid)
+QVariant RDGetSqlValue(const QString &table,const QString &name,
+		       const QString &test,const QString &param,
+		       QSqlDatabase *db,bool *valid)
 {
   RDSqlQuery *q;
   QString sql;
   QVariant v;
 
   sql=QString().sprintf("SELECT %s FROM %s WHERE %s=\"%s\"",
-			(const char *)param,
-			(const char *)table,
-			(const char *)name,
-			(const char *)test);
+			(const char *)RDEscapeStringSQLColumn(param),
+			(const char *)RDEscapeStringSQLColumn(table),
+			(const char *)RDEscapeStringSQLColumn(name),
+			(const char *)RDEscapeString(test));
   q=new RDSqlQuery(sql,db);
   if(q->isActive()) {
     q->first();
@@ -584,17 +595,17 @@ QVariant RDGetSqlValue(QString table,QString name,QString test,
 }
 
 
-bool RDIsSqlNull(QString table,QString name,QString test,
-		QString param,QSqlDatabase *db)
+bool RDIsSqlNull(const QString &table,const QString &name,const QString &test,
+		 const QString &param,QSqlDatabase *db)
 {
   RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("SELECT %s FROM %s WHERE %s=\"%s\"",
-			(const char *)param,
-			(const char *)table,
-			(const char *)name,
-			(const char *)test);
+			(const char *)RDEscapeStringSQLColumn(param),
+			(const char *)RDEscapeStringSQLColumn(table),
+			(const char *)RDEscapeStringSQLColumn(name),
+			(const char *)RDEscapeString(test));
   q=new RDSqlQuery(sql,db);
   if(q->isActive()) {
     q->first();
@@ -612,16 +623,16 @@ bool RDIsSqlNull(QString table,QString name,QString test,
 }
 
 
-bool RDIsSqlNull(QString table,QString name,unsigned test,
-		QString param,QSqlDatabase *db)
+bool RDIsSqlNull(const QString &table,const QString &name,unsigned test,
+		 const QString &param,QSqlDatabase *db)
 {
   RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("SELECT %s FROM %s WHERE %s=%d",
-			(const char *)param,
-			(const char *)table,
-			(const char *)name,
+			(const char *)RDEscapeStringSQLColumn(param),
+			(const char *)RDEscapeStringSQLColumn(table),
+			(const char *)RDEscapeStringSQLColumn(name),
 			test);
   q=new RDSqlQuery(sql,db);
   if(q->isActive()) {
@@ -640,17 +651,17 @@ bool RDIsSqlNull(QString table,QString name,unsigned test,
 }
 
 
-QVariant RDGetSqlValue(QString table,QString name,unsigned test,
-		      QString param,QSqlDatabase *db,bool *valid)
+QVariant RDGetSqlValue(const QString &table,const QString &name,unsigned test,
+		       const QString &param,QSqlDatabase *db,bool *valid)
 {
   RDSqlQuery *q;
   QString sql;
   QVariant v;
 
   sql=QString().sprintf("SELECT %s FROM %s WHERE %s=%u",
-			(const char *)param,
-			(const char *)table,
-			(const char *)name,
+			(const char *)RDEscapeStringSQLColumn(param),
+			(const char *)RDEscapeStringSQLColumn(table),
+			(const char *)RDEscapeStringSQLColumn(name),
 			test);
   q=new RDSqlQuery(sql,db);
   if(q->first()) {
@@ -712,7 +723,7 @@ QString RDGetTimeLength(int mseconds,bool leadzero,bool tenths)
 }
 
 
-int RDSetTimeLength(QString str)
+int RDSetTimeLength(const QString &str)
 {
   int istate=2;
   QString field;
@@ -791,7 +802,7 @@ int RDSetTimeLength(QString str)
 
 
 #ifndef WIN32
-bool RDCopy(QString srcfile,QString destfile)
+bool RDCopy(const QString &srcfile,const QString &destfile)
 {
   int src_fd;
   int dest_fd;
@@ -831,7 +842,8 @@ bool RDCopy(QString srcfile,QString destfile)
 
 
 #ifndef WIN32
-bool RDWritePid(QString dirname,QString filename,int owner,int group)
+bool RDWritePid(const QString &dirname,const QString &filename,int owner,
+		int group)
 {
   FILE *file;
   mode_t prev_mask;
@@ -853,7 +865,7 @@ bool RDWritePid(QString dirname,QString filename,int owner,int group)
 }
 
 
-void RDDeletePid(QString dirname,QString filename)
+void RDDeletePid(const QString &dirname,const QString &filename)
 {
   QString pid=QString().sprintf("%s/%s",
 				(const char *)dirname,
@@ -862,7 +874,7 @@ void RDDeletePid(QString dirname,QString filename)
 }
 
 
-bool RDCheckPid(QString dirname,QString filename)
+bool RDCheckPid(const QString &dirname,const QString &filename)
 {
   QDir dir;
   QString path;
@@ -873,7 +885,7 @@ bool RDCheckPid(QString dirname,QString filename)
 }
 
 
-pid_t RDGetPid(QString pidfile)
+pid_t RDGetPid(const QString &pidfile)
 {
   FILE *handle;
   pid_t ret;
@@ -978,3 +990,39 @@ QString RDTimeZoneName(const QDateTime &datetime)
   return QString(name);
 }
 #endif  // WIN32
+
+
+QString RDDowCode(int dow)
+{
+  QString ret;
+  switch(dow) {
+    case 1:
+      ret=QString("MON");
+      break;
+
+    case 2:
+      ret=QString("TUE");
+      break;
+
+    case 3:
+      ret=QString("WED");
+      break;
+
+    case 4:
+      ret=QString("THU");
+      break;
+
+    case 5:
+      ret=QString("FRI");
+      break;
+
+    case 6:
+      ret=QString("SAT");
+      break;
+
+    case 7:
+      ret=QString("SUN");
+      break;
+  }
+  return ret;
+}
