@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdfeed.h,v 1.5.2.5 2009/05/26 18:33:29 cvs Exp $
+//      $Id: rdfeed.h,v 1.5.2.6 2009/09/04 01:29:49 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,7 @@
 #include <qsqldatabase.h>
 #include <qobject.h>
 
+#include <rdstation.h>
 #include <rdsettings.h>
 
 #ifndef RDFEED_H
@@ -105,8 +106,8 @@ class RDFeed : public QObject
   RDFeed::MediaLinkMode mediaLinkMode() const;
   void setMediaLinkMode(RDFeed::MediaLinkMode mode) const;
   QString audioUrl(RDFeed::MediaLinkMode mode,unsigned cast_id);
-  unsigned postCut(const QString &cutname,Error *err);
-  unsigned postFile(const QString &srcfile,Error *err);
+  unsigned postCut(RDStation *station,const QString &cutname,Error *err);
+  unsigned postFile(RDStation *station,const QString &srcfile,Error *err);
   int totalPostSteps() const;
   static QString errorString(RDFeed::Error err);
 
@@ -114,10 +115,10 @@ class RDFeed : public QObject
   void postProgressChanged(int step);
 
  private:
-  QString GetImportCommand(const QString &srcfile,QString *destfile,
-			   Error *err) const;
-  QString GetExportCommand(const QString &srcfile,QString *destfile,
-			   Error *err) const;
+  QString GetImportCommand(RDStation *station,const QString &srcfile,
+			   QString *destfile,Error *err) const;
+  QString GetExportCommand(RDStation *station,const QString &srcfile,
+			   QString *destfile,Error *err) const;
   unsigned CreateCast(QString *filename,int bytes,int msecs) const;
   QString GetTempFilename() const;
   void SetRow(const QString &param,int value) const;
