@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport_audio.cpp,v 1.22 2008/09/26 17:52:22 fredg Exp $
+//      $Id: rdimport_audio.cpp,v 1.22.2.2 2010/02/09 21:43:53 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,7 +42,7 @@
 #include <rdescape_string.h>
 #include <rdstation.h>
 #include <rdimport_audio.h>
-
+#include <rdlibrary_conf.h>
 
 RDImportAudio::RDImportAudio(QString cutname,QString *path,
 			     RDSettings *settings,bool *import_metadata,
@@ -320,6 +320,38 @@ QSizePolicy RDImportAudio::sizePolicy() const
 }
 
 
+void RDImportAudio::enableAutotrim(bool state)
+{
+  import_autotrim_box->setChecked(state);
+  autotrimCheckData(state);
+}
+
+
+void RDImportAudio::setAutotrimLevel(int lvl)
+{
+  import_autotrim_spin->setValue(lvl/100);
+}
+
+
+void RDImportAudio::enableNormalization(bool state)
+{
+  import_normalize_box->setChecked(state);
+  normalizeCheckData(state);
+}
+
+
+void RDImportAudio::setNormalizationLevel(int lvl)
+{
+  import_normalize_spin->setValue(lvl/100);
+}
+
+
+void RDImportAudio::setChannels(int chans)
+{
+  import_channels_box->setCurrentItem(chans-1);
+}
+
+
 int RDImportAudio::exec(bool enable_import,bool enable_export)
 {
   import_importmode_button->setEnabled(enable_import);
@@ -329,9 +361,12 @@ int RDImportAudio::exec(bool enable_import,bool enable_export)
   import_in_selector_button->setEnabled(enable_import);
   import_channels_label->setEnabled(enable_import);
   import_autotrim_box->setEnabled(enable_import);
-  import_autotrim_spin->setEnabled(enable_import);
-  import_autotrim_label->setEnabled(enable_import);
-  import_autotrim_unit->setEnabled(enable_import);
+  import_autotrim_spin->
+    setEnabled(enable_import&&import_autotrim_box->isChecked());
+  import_autotrim_label->
+    setEnabled(enable_import&&import_autotrim_box->isChecked());
+  import_autotrim_unit->
+    setEnabled(enable_import&&import_autotrim_box->isChecked());
   import_channels_box->setEnabled(enable_import);
 
   import_exportmode_button->setEnabled(enable_export);
@@ -618,11 +653,12 @@ void RDImportAudio::Import()
 
   QString cmd;
   float normal=0.0;
+  RDLibraryConf *rdlibrary=new RDLibraryConf(import_station->name(),0);
   if(import_normalize_box->isChecked()) {
     normal=pow(10.0,(double)(import_normalize_spin->value())/20.0);
     import_multipass=true;
     cmd=QString().
-      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s",
+      sprintf("rd_import_file %6.4f %d %d %s %d %d %d %d %s %s %s %d",
 	      normal,
 	      format_in,
 	      samplerate,
@@ -634,12 +670,13 @@ void RDImportAudio::Import()
 	       currentItem()+1)*import_default_settings->bitRate()/1000,
 	      RDCut::pathName(import_cutname).ascii(),  
 	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name);
+	      (const char *)import_tempwav_name,
+	      rdlibrary->srcConverter());
   }
   else {
     import_multipass=false;
     cmd=QString().
-      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s %s",
+      sprintf("rd_import_file 0 %d %d %s %d %d %d %d %s %s %s %d",
 	      format_in,
 	      samplerate,
 	      (const char *)RDEscapeString(import_in_filename_edit->text()).utf8(),
@@ -650,9 +687,11 @@ void RDImportAudio::Import()
 	       currentItem()+1)*import_default_settings->bitRate()/1000,
 	      RDCut::pathName(import_cutname).ascii(),  
 	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name);
+	      (const char *)import_tempwav_name,
+	      rdlibrary->srcConverter());
   }
   // printf("CMD: %s\n",(const char *)cmd);
+  delete rdlibrary;
   *import_running=true;
   import_import_aborted=false;
   import_in_selector_button->setDisabled(true);
@@ -854,11 +893,12 @@ void RDImportAudio::Export()
 
   QString cmd;
   float normal=0.0;
+  RDLibraryConf *rdlibrary=new RDLibraryConf(import_station->name(),0);
   if(import_normalize_box->isChecked()) {
     normal=pow(10.0,(double)(import_normalize_spin->value())/20.0);
     import_multipass=true;
     cmd=QString().
-      sprintf("rd_export_file %6.4f %d %d %s %d %d %d %d %d %s %s %s",
+      sprintf("rd_export_file %6.4f %d %d %s %d %d %d %d %d %s %s %s %d",
 	      normal,
 	      format_in,
 	      samplerate,
@@ -870,12 +910,13 @@ void RDImportAudio::Export()
 	      import_settings->quality(),
 	      (const char *)RDEscapeString(import_out_filename_edit->text()).utf8(),
 	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name);
+	      (const char *)import_tempwav_name,
+	      rdlibrary->srcConverter());
   }
   else {
     import_multipass=false;
     cmd=QString().
-      sprintf("rd_export_file 0 %d %d %s %d %d %d %d %d %s %s %s",
+      sprintf("rd_export_file 0 %d %d %s %d %d %d %d %d %s %s %s %d",
 	      format_in,
 	      samplerate,
 	      RDCut::pathName(import_cutname).ascii(),  
@@ -886,13 +927,15 @@ void RDImportAudio::Export()
 	      import_settings->quality(),
 	      (const char *)RDEscapeString(import_out_filename_edit->text()).utf8(),  
 	      (const char *)import_tempdat_name,
-	      (const char *)import_tempwav_name);
+	      (const char *)import_tempwav_name,
+	      rdlibrary->srcConverter());
   }
+  delete rdlibrary;
   if(!custom_cmd.isEmpty()) {
     cmd+=" \""+custom_cmd+"\"";
     import_bar->setDisabled(true);
   }
-  printf("CMD: %s\n",(const char *)cmd);
+  //printf("CMD: %s\n",(const char *)cmd);
   *import_running=true;
   import_import_aborted=false;
   import_out_selector_button->setDisabled(true);
