@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport_audio.h,v 1.8 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdimport_audio.h,v 1.8.2.1 2010/02/09 21:43:53 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -68,6 +68,11 @@ class RDImportAudio : public QDialog
   ~RDImportAudio();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
+  void enableAutotrim(bool state);
+  void setAutotrimLevel(int lvl);
+  void enableNormalization(bool state);
+  void setNormalizationLevel(int lvl);
+  void setChannels(int chans);
 
  public slots:
   int exec(bool enable_import,bool enable_export);
