@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_line.h,v 1.81.2.1 2008-12-03 20:24:41 fredg Exp $
+//      $Id: rdlog_line.h,v 1.81.2.2 2009/11/17 17:45:53 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -60,6 +60,7 @@ class RDLogLine
   RDLogLine::State state() const;
   void setState(RDLogLine::State state);
   RDCart::Validity validity() const;
+  RDCart::Validity validity(const QDateTime &datetime) const;
   void setValidity(RDCart::Validity valid);
   unsigned pass() const;
   void incrementPass();
@@ -162,6 +163,10 @@ class RDLogLine
   void setEnforceLength(bool state);
   bool preservePitch() const;
   void setPreservePitch(bool state);
+  QDateTime startDatetime() const;
+  void setStartDatetime(const QDateTime &datetime);
+  QDateTime endDatetime() const;
+  void setEndDatetime(const QDateTime &datetime);
   RDListViewItem *listViewItem() const;
   void setListViewItem(RDListViewItem *);
   RDLogLine::Type type() const;
@@ -290,6 +295,8 @@ class RDLogLine
   RDCart::PlayOrder log_play_order;
   bool log_enforce_length;
   bool log_preserve_pitch;
+  QDateTime log_start_datetime;
+  QDateTime log_end_datetime;
   int log_deck;
   QTime log_play_time;
   int log_cut_number;
