@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpodcast.cpp,v 1.6 2007/11/06 16:25:56 fredg Exp $
+//      $Id: rdpodcast.cpp,v 1.6.2.1 2009/01/30 19:51:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -193,6 +193,19 @@ void RDPodcast::setOriginDateTime(const QDateTime &datetime) const
 }
 
 
+QDateTime RDPodcast::effectiveDateTime() const
+{
+  return RDGetSqlValue("PODCASTS","ID",podcast_id,
+		       "EFFECTIVE_DATETIME").toDateTime();
+}
+
+
+void RDPodcast::setEffectiveDateTime(const QDateTime &datetime) const
+{
+  SetRow("EFFECTIVE_DATETIME",datetime.toString("yyyy-MM-dd hh:mm:ss"));
+}
+
+
 QString RDPodcast::audioFilename() const
 {
   return RDGetSqlValue("PODCASTS","ID",podcast_id,
