@@ -2,9 +2,9 @@
 //
 //   A class for handling Microsoft WAV files.
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdwavefile.cpp,v 1.13 2008-10-16 19:28:38 fredg Exp $
+//    $Id: rdwavefile.cpp,v 1.13.2.6 2010/01/22 21:04:15 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -43,7 +43,6 @@
 #include <rdwavefile.h>
 #include <rdconf.h>
 
-
 RDWaveFile::RDWaveFile(QString file_name)
 {
   // 
@@ -268,7 +267,7 @@ bool RDWaveFile::openWave(RDWaveData *data)
 	GetCart(wave_file.handle());
 	GetBext(wave_file.handle());
 	GetMext(wave_file.handle());
-	GetLevl(wave_file.handle());
+//	GetLevl(wave_file.handle());
 	GetList(wave_file.handle());
 	GetScot(wave_file.handle());
 	GetAv10(wave_file.handle());
@@ -1905,12 +1904,12 @@ RDWaveFile::Type RDWaveFile::GetType(int fd)
   if(IsTmc(fd)) {
     return RDWaveFile::Tmc;
   }
-  if(IsMpeg(fd)) {
-    return RDWaveFile::Mpeg;
-  }
   if(IsOgg(fd)) {
     return RDWaveFile::Ogg;
   }
+  if(IsMpeg(fd)) {
+    return RDWaveFile::Mpeg;
+  }
   return RDWaveFile::Unknown;
 }
 
@@ -1969,7 +1968,6 @@ bool RDWaveFile::IsMpeg(int fd)
 
   lseek(fd,0,SEEK_SET);
   if((i=read(fd,buffer,10))!=10) {
-    printf("HERE1\n");
     return false;
   }
   buffer[3]=0;
@@ -1980,23 +1978,12 @@ bool RDWaveFile::IsMpeg(int fd)
   }  
   lseek(fd,id3v2_offset[0],SEEK_SET);
   if((i=read(fd,buffer,2))!=2) {
-    printf("HERE2\n");
     return false;
   }
-//  if((buffer[0]==0xFF)&&((buffer[1]&0xF0)==0xF0)) {
   if((buffer[0]==0xFF)&&((buffer[1]&0xE0)==0xE0)) {
     return true;
-/*
-    lseek(fd,-128,SEEK_END);
-    i=read(fd,buffer,3);
-    buffer[3]=0;
-    if(!strcasecmp("TAG",(char *)buffer)) {
-      id3v1_tag=true;
-    }
-    return true;
-*/
   }
-  if(buffer[0]==0) {   // Possibly a broken null-padded ID3 tag -- see if
+//  if(buffer[0]==0) {   // Possibly a broken null-padded ID3 tag -- see if
                        // we can find the start of the MPEG data
     while(read(fd,buffer,1)==1) {
       if(buffer[0]==0xFF) {  // Could be it -- check the next byte
@@ -2009,8 +1996,7 @@ bool RDWaveFile::IsMpeg(int fd)
 	}
       }
     }
-  }
-    printf("HERE3\n");
+//  }
   return false;
 }
 
@@ -2274,6 +2260,7 @@ bool RDWaveFile::GetCart(int fd)
     cart_tag_text="";
   }
 
+
   if(wave_data!=NULL) {
     wave_data->setMetadataFound(true);
     wave_data->setTitle(cart_title);
@@ -2697,7 +2684,6 @@ bool RDWaveFile::GetList(int fd)
   if((wave_data->segueStartPos()>=0)&&(wave_data->segueEndPos()<0)) {
     wave_data->setSegueEndPos(ext_time_length);
   }
-  delete chunk_data;
   return true;
 }
 
@@ -3201,69 +3187,6 @@ bool RDWaveFile::GetMpegHeader(int fd,int offset)
       case RDWaveFile::Mpeg2:
 	switch(head_layer) {
 	    case 1:
-	      switch(buffer[2]>>4) {
-		  case 1:
-		    head_bit_rate=32000;
-		    break;
-	
-		  case 2:
-		    head_bit_rate=64000;
-		    break;
-	
-		  case 3:
-		    head_bit_rate=96000;
-		    break;
-	
-		  case 4:
-		    head_bit_rate=128000;
-		    break;
-	
-		  case 5:
-		    head_bit_rate=160000;
-		    break;
-	
-		  case 6:
-		    head_bit_rate=192000;
-		    break;
-	
-		  case 7:
-		    head_bit_rate=224000;
-		    break;
-	
-		  case 8:
-		    head_bit_rate=256000;
-		    break;
-	
-		  case 9:
-		    head_bit_rate=288000;
-		    break;
-	
-		  case 10:
-		    head_bit_rate=320000;
-		    break;
-	
-		  case 11:
-		    head_bit_rate=352000;
-		    break;
-	
-		  case 12:
-		    head_bit_rate=384000;
-		    break;
-	
-		  case 13:
-		    head_bit_rate=416000;
-		    break;
-	
-		  case 14:
-		    head_bit_rate=448000;
-		    break;
-
-		  default:
-		    return false;
-	      }
-	      break;
-
-	    case 2:
 	      switch(buffer[2]>>4) {
 		  case 1:
 		    head_bit_rate=32000;
@@ -3298,27 +3221,90 @@ bool RDWaveFile::GetMpegHeader(int fd,int offset)
 		    break;
 	
 		  case 9:
-		    head_bit_rate=160000;
+		    head_bit_rate=144000;
 		    break;
 	
 		  case 10:
-		    head_bit_rate=192000;
+		    head_bit_rate=160000;
 		    break;
 	
 		  case 11:
-		    head_bit_rate=224000;
+		    head_bit_rate=176000;
 		    break;
 	
 		  case 12:
-		    head_bit_rate=256000;
+		    head_bit_rate=192000;
 		    break;
 	
 		  case 13:
-		    head_bit_rate=320000;
+		    head_bit_rate=224000;
 		    break;
 	
 		  case 14:
-		    head_bit_rate=384000;
+		    head_bit_rate=256000;
+		    break;
+
+		  default:
+		    return false;
+	      }
+	      break;
+
+	    case 2:
+	      switch(buffer[2]>>4) {
+		  case 1:
+		    head_bit_rate=8000;
+		    break;
+	
+		  case 2:
+		    head_bit_rate=16000;
+		    break;
+	
+		  case 3:
+		    head_bit_rate=24000;
+		    break;
+	
+		  case 4:
+		    head_bit_rate=32000;
+		    break;
+	
+		  case 5:
+		    head_bit_rate=40000;
+		    break;
+	
+		  case 6:
+		    head_bit_rate=48000;
+		    break;
+	
+		  case 7:
+		    head_bit_rate=56000;
+		    break;
+	
+		  case 8:
+		    head_bit_rate=64000;
+		    break;
+	
+		  case 9:
+		    head_bit_rate=80000;
+		    break;
+	
+		  case 10:
+		    head_bit_rate=96000;
+		    break;
+	
+		  case 11:
+		    head_bit_rate=112000;
+		    break;
+	
+		  case 12:
+		    head_bit_rate=128000;
+		    break;
+	
+		  case 13:
+		    head_bit_rate=144000;
+		    break;
+	
+		  case 14:
+		    head_bit_rate=160000;
 		    break;
 
 		  default:
@@ -3346,11 +3332,11 @@ bool RDWaveFile::GetMpegHeader(int fd,int offset)
 		    break;
 	
 		  case 5:
-		    head_bit_rate=64000;
+		    head_bit_rate=40000;
 		    break;
 	
 		  case 6:
-		    head_bit_rate=80000;
+		    head_bit_rate=48000;
 		    break;
 	
 		  case 7:
@@ -3362,11 +3348,11 @@ bool RDWaveFile::GetMpegHeader(int fd,int offset)
 		    break;
 	
 		  case 9:
-		    head_bit_rate=128000;
+		    head_bit_rate=80000;
 		    break;
 	
 		  case 10:
-		    head_bit_rate=160000;
+		    head_bit_rate=96000;
 		    break;
 	
 		  case 11:
@@ -3378,11 +3364,11 @@ bool RDWaveFile::GetMpegHeader(int fd,int offset)
 		    break;
 	
 		  case 13:
-		    head_bit_rate=256000;
+		    head_bit_rate=144000;
 		    break;
 	
 		  case 14:
-		    head_bit_rate=320000;
+		    head_bit_rate=160000;
 		    break;
 
 		  default:
@@ -3534,6 +3520,78 @@ bool RDWaveFile::GetFlacStreamInfo()
 
 void RDWaveFile::ReadFlacMetadata()
 {
+#ifdef HAVE_FLAC_METADATA
+  QString artist;
+  QString composer;
+  FLAC__StreamMetadata* tags;
+  if(!FLAC__metadata_get_tags(QCString().
+	    sprintf("%s",(const char *)wave_file.name().utf8()),&tags)) {
+    return;
+  }
+  for(int iCommentIndex=0;iCommentIndex<tags->data.vorbis_comment.num_comments;
+      ++iCommentIndex)
+  {
+    FLAC__StreamMetadata_VorbisComment_Entry&
+      comment(tags->data.vorbis_comment.comments[iCommentIndex]);
+	   
+    // comment.entry is a UTF-8 string of comment.length octets 
+    // (http://www.xiph.org/vorbis/doc/v-comment.html)
+    QString entry=
+      QString::fromUtf8((const char *)comment.entry, comment.length);
+	   
+    // every entry is a name=value pair. Name is not allowed to contain a '='
+    // so we just scan to the first instance of it.
+    int nameLength = entry.find('=');
+    if(nameLength < 0) continue; // malformed comment, it would seem
+    QString name = entry.left(nameLength), value = entry.mid(nameLength + 1);
+	   
+    if(name=="TITLE") { 
+      wave_data->setTitle(value); 
+      wave_data->setMetadataFound(true); 
+      continue;
+    }
+    if(name=="ARTIST") { 
+      composer=value;
+      wave_data->setMetadataFound(true);
+      continue;
+    }
+    if(name=="PERFORMER") { 
+      artist=value;
+      wave_data->setMetadataFound(true);
+    }
+    if(name=="ALBUM") { 
+      wave_data->setAlbum(value);
+      wave_data->setMetadataFound(true);
+      continue;
+    }
+    if(name=="ORGANIZATION") {
+      wave_data->setLabel(value);
+      wave_data->setMetadataFound(true);
+      continue;
+    }
+    // TODO: Parse the date field to get the year out
+    //if(name == "DATE") { wave_data->setReleaseYear(value);
+    //wave_data->setMetadataFound(true); continue; }
+    if(name=="ISRC") { 
+      wave_data->setIsrc(value); 
+      wave_data->setMetadataFound(true); 
+      continue; 
+    }
+  }
+  if((!artist.isEmpty())&&(!composer.isEmpty())) {
+    wave_data->setArtist(artist);
+    wave_data->setComposer(composer);
+  }
+  else {
+    if(!artist.isEmpty()) {
+      wave_data->setArtist(artist);
+    }
+    else {
+      wave_data->setArtist(composer);
+    }
+  }
+  FLAC__metadata_object_delete(tags);
+#endif  // HAVE_FLAC_METADATA
 }
 
 
@@ -3892,6 +3950,9 @@ void RDWaveFile::GetEnergy()
 {
   int file_ptr;
 
+  if(!levl_chunk) {
+    GetLevl(wave_file.handle());
+  }
   if(energy_loaded) {
     return;
   }
@@ -3990,6 +4051,7 @@ void RDWaveFile::ValidateMetadata()
   if(wave_data==NULL) {
     return;
   }
+
   if(!wave_data->metadataFound()) {
     return;
   }
