@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdwavepainter.h,v 1.5 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdwavepainter.h,v 1.7 2007/12/29 18:16:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,10 +24,10 @@
 #define RDWAVEPAINTER_H
 
 #include <qpainter.h>
-#include <rwavefile.h>
+#include <rdwavefile.h>
 
 
-class RDWavePainter : public QPainter,public RWaveFile
+class RDWavePainter : public QPainter,public RDWaveFile
 {
  public:
   enum Channel {Mono=0,Left=1,Right=2};
@@ -36,6 +36,7 @@ class RDWavePainter : public QPainter,public RWaveFile
   ~RDWavePainter();
   void nameWave(QString file_name);
   bool begin(const QPaintDevice *pd,const QString &wavname);
+  bool begin(const QPaintDevice *pd);
   bool end();
   void drawWaveBySamples(int x,int w,int startsamp,int endsamp,int gain,
 			 Channel channel,const QColor &color,
