@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_feed.cpp,v 1.5 2008/09/26 17:52:23 fredg Exp $
+//      $Id: edit_feed.cpp,v 1.5.2.5 2009/05/26 18:33:30 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -49,7 +49,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  feed_feed=new RDFeed(feed);
+  feed_feed=new RDFeed(feed,this,"feed_feed");
 
   setCaption(tr("Feed: ")+feed);
 
@@ -77,10 +77,10 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   //
   // Channel Section
   //
-  QLabel *label=new QLabel("CHANNEL VALUES",this);
-  label->setGeometry(30,41,130,20);
-  label->setAlignment(AlignCenter);
-  label->setFont(font);
+  feed_channel_section_label=new QLabel("CHANNEL VALUES",this);
+  feed_channel_section_label->setGeometry(30,41,130,20);
+  feed_channel_section_label->setAlignment(AlignCenter);
+  feed_channel_section_label->setFont(font);
 
   //
   // Channel Title
@@ -88,7 +88,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_channel_title_edit=new QLineEdit(this,"feed_channel_title_edit");
   feed_channel_title_edit->setGeometry(115,60,375,19);
   feed_channel_title_edit->setMaxLength(255);
-  QLabel *feed_channel_title_label=
+  feed_channel_title_label=
     new QLabel(feed_channel_title_edit,tr("Title:"),this,
 	       "feed_channel_title_label");
   feed_channel_title_label->setGeometry(20,60,90,19);
@@ -101,7 +101,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_channel_category_edit=new QLineEdit(this,"feed_channel_category_edit");
   feed_channel_category_edit->setGeometry(115,82,375,19);
   feed_channel_category_edit->setMaxLength(64);
-  QLabel *feed_channel_category_label=
+  feed_channel_category_label=
     new QLabel(feed_channel_category_edit,tr("Category:"),this,
 	       "feed_channel_category_label");
   feed_channel_category_label->setGeometry(20,82,90,19);
@@ -115,7 +115,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_channel_link_edit=new QLineEdit(this,"feed_channel_link_edit");
   feed_channel_link_edit->setGeometry(115,104,375,19);
   feed_channel_link_edit->setMaxLength(255);
-  QLabel *feed_channel_link_label=
+  feed_channel_link_label=
     new QLabel(feed_channel_link_edit,tr("Link:"),this,
 	       "feed_channel_link_label");
   feed_channel_link_label->setGeometry(20,104,90,19);
@@ -129,7 +129,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     new QLineEdit(this,"feed_channel_copyright_edit");
   feed_channel_copyright_edit->setGeometry(115,126,375,19);
   feed_channel_copyright_edit->setMaxLength(64);
-  QLabel *feed_channel_copyright_label=
+  feed_channel_copyright_label=
     new QLabel(feed_channel_copyright_edit,tr("Copyright:"),this,
 	       "feed_channel_copyright_label");
   feed_channel_copyright_label->setGeometry(20,126,90,19);
@@ -144,7 +144,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     new QLineEdit(this,"feed_channel_webmaster_edit");
   feed_channel_webmaster_edit->setGeometry(115,148,375,19);
   feed_channel_webmaster_edit->setMaxLength(64);
-  QLabel *feed_channel_webmaster_label=
+  feed_channel_webmaster_label=
     new QLabel(feed_channel_webmaster_edit,tr("Webmaster:"),this,
 	       "feed_channel_webmaster_label");
   feed_channel_webmaster_label->setGeometry(20,148,90,19);
@@ -160,7 +160,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_channel_language_edit->
     setGeometry(115,170,60,19);
   feed_channel_language_edit->setMaxLength(5);
-  QLabel *feed_channel_language_label=
+  feed_channel_language_label=
     new QLabel(feed_channel_language_edit,tr("Language:"),this,
 	       "feed_channel_language_label");
   feed_channel_language_label->setGeometry(20,170,90,19);
@@ -175,7 +175,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     new QTextEdit(this,"feed_channel_description_edit");
   feed_channel_description_edit->
     setGeometry(115,192,375,76);
-  QLabel *feed_channel_description_label=
+  feed_channel_description_label=
     new QLabel(feed_channel_description_edit,tr("Description:"),this,
 	       "feed_channel_description_label");
   feed_channel_description_label->setGeometry(20,192,90,19);
@@ -192,7 +192,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_purge_url_edit->setMaxLength(255);
   connect(feed_purge_url_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(purgeUrlChangedData(const QString &)));
-  QLabel *feed_purge_url_label=
+  feed_purge_url_label=
     new QLabel(feed_purge_url_edit,tr("Audio Upload URL:"),this,
 	       "feed_purge_url_label");
   feed_purge_url_label->setGeometry(20,280,130,19);
@@ -236,16 +236,16 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_format_edit=new QLineEdit(this,"feed_format_edit");
   feed_format_edit->setGeometry(155,324,285,20);
   feed_format_edit->setReadOnly(true);
-  label=new QLabel(feed_format_edit,
+  feed_format_label=new QLabel(feed_format_edit,
 		   tr("Upload Format:"),this,"feed_format_label");
-  label->setGeometry(5,324,145,20);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  QPushButton *button=new QPushButton(this,"format_button");
-  button->setGeometry(450,324,40,24);
-  button->setFont(small_font);
-  button->setText(tr("S&et"));
-  connect(button,SIGNAL(clicked()),this,SLOT(setFormatData()));
+  feed_format_label->setGeometry(5,324,145,20);
+  feed_format_label->setFont(font);
+  feed_format_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_format_button=new QPushButton(this,"format_button");
+  feed_format_button->setGeometry(450,324,40,24);
+  feed_format_button->setFont(small_font);
+  feed_format_button->setText(tr("S&et"));
+  connect(feed_format_button,SIGNAL(clicked()),this,SLOT(setFormatData()));
 
   //
   // Normalize Check Box
@@ -253,11 +253,11 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_normalize_box=new QCheckBox(this,"feed_normalize_box");
   feed_normalize_box->setGeometry(155,348,15,15);
   feed_normalize_box->setChecked(true);
-  label=new QLabel(feed_normalize_box,tr("Normalize"),
+  feed_normalize_check_label=new QLabel(feed_normalize_box,tr("Normalize"),
 		   this,"normalize_check_label");
-  label->setGeometry(175,346,83,20);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  feed_normalize_check_label->setGeometry(175,346,83,20);
+  feed_normalize_check_label->setFont(font);
+  feed_normalize_check_label->setAlignment(AlignLeft|AlignVCenter);
   connect(feed_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeCheckData(bool)));
 
@@ -272,10 +272,10 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_normalize_label->setGeometry(245,346,45,20);
   feed_normalize_label->setFont(font);
   feed_normalize_label->setAlignment(AlignRight|AlignVCenter);
-  feed_normalize_unit=new QLabel(tr("dBFS"),this,"normalize_unit_label");
-  feed_normalize_unit->setGeometry(340,346,40,20);
-  feed_normalize_unit->setFont(font);
-  feed_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
+  feed_normalize_unit_label=new QLabel(tr("dBFS"),this,"normalize_unit_label");
+  feed_normalize_unit_label->setGeometry(340,346,40,20);
+  feed_normalize_unit_label->setFont(font);
+  feed_normalize_unit_label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Base Audio URL
@@ -284,7 +284,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     new QLineEdit(this,"feed_base_url_edit");
   feed_base_url_edit->setGeometry(155,368,335,19);
   feed_base_url_edit->setMaxLength(255);
-  QLabel *feed_base_url_label=
+  feed_base_url_label=
     new QLabel(feed_base_url_edit,tr("Audio Download URL:"),this,
 	       "feed_base_url_label");
   feed_base_url_label->setGeometry(20,368,130,19);
@@ -296,7 +296,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   //
   feed_keep_metadata_box=new QCheckBox(this,"feed_keep_metadata_box");
   feed_keep_metadata_box->setGeometry(155,390,15,15);
-  QLabel *feed_keep_metadata_label=
+  feed_keep_metadata_label=
     new QLabel(feed_keep_metadata_box,tr("Keep Expired Metadata"),this,
 	       "feed_keep_metadata_label");
   feed_keep_metadata_label->setGeometry(175,390,180,19);
@@ -308,57 +308,109 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   //
   feed_autopost_box=new QCheckBox(this,"feed_autopost_box");
   feed_autopost_box->setGeometry(365,390,15,15);
-  QLabel *feed_autopost_label=
+  feed_autopost_label=
     new QLabel(feed_autopost_box,tr("Enable AutoPost"),this,
 	       "feed_autopost_label");
   feed_autopost_label->setGeometry(385,390,200,19);
   feed_autopost_label->setFont(font);
   feed_autopost_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
  
+  //
+  // Enclosure Preamble
+  //
+  feed_base_preamble_edit=
+    new QLineEdit(this,"feed_base_preamble_edit");
+  feed_base_preamble_edit->setGeometry(155,412,335,19);
+  feed_base_preamble_edit->setMaxLength(255);
+  feed_base_preamble_label=
+    new QLabel(feed_base_preamble_edit,tr("Enclosure Preamble:"),this,
+	       "feed_base_preamble_label");
+  feed_base_preamble_label->setGeometry(20,412,130,19);
+  feed_base_preamble_label->setFont(font);
+  feed_base_preamble_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
   //
   // Audio File Extension
   //
   feed_extension_edit=new QLineEdit(this,"feed_extension_edit");
-  feed_extension_edit->setGeometry(155,412,70,19);
+  feed_extension_edit->setGeometry(155,434,70,19);
   feed_extension_edit->setMaxLength(16);
-  label=
+  feed_extension_label=
     new QLabel(feed_extension_edit,tr("Audio Extension:"),this,
 	       "feed_extension_label");
-  label->setGeometry(20,412,130,19);
-  label->setFont(font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  feed_extension_label->setGeometry(20,434,130,19);
+  feed_extension_label->setFont(font);
+  feed_extension_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Maximum Shelf Life
   //
   feed_max_shelf_life_spin=
     new QSpinBox(this,"feed_max_shelf_life_spin");
-  feed_max_shelf_life_spin->setGeometry(155,434,60,19);
+  feed_max_shelf_life_spin->setGeometry(155,456,60,19);
   feed_max_shelf_life_spin->setRange(0,365);
   feed_max_shelf_life_spin->setSpecialValueText(tr("None"));
-  QLabel *feed_max_shelf_life_label=
+  feed_max_shelf_life_label=
     new QLabel(feed_max_shelf_life_spin,tr("Maximum Shelf Life:"),this,
 	       "feed_max_shelf_life_label");
-  feed_max_shelf_life_label->setGeometry(20,434,130,19);
+  feed_max_shelf_life_label->setGeometry(20,456,130,19);
   feed_max_shelf_life_label->setFont(font);
   feed_max_shelf_life_label->
     setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  QLabel *feed_max_shelf_life_unit=
+  feed_max_shelf_life_unit_label=
     new QLabel(feed_max_shelf_life_spin,tr("days"),this,
 	       "feed_max_shelf_life_unit");
-  feed_max_shelf_life_unit->setGeometry(220,434,50,19);
-  feed_max_shelf_life_unit->setFont(font);
-  feed_max_shelf_life_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  feed_max_shelf_life_unit_label->setGeometry(220,456,50,19);
+  feed_max_shelf_life_unit_label->setFont(font);
+  feed_max_shelf_life_unit_label->
+    setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
 
   //
-  //  Metadata Button
+  // Episode Order
   //
-  button=new QPushButton(this,"edit_button");
-  button->setGeometry(190,461,150,50);
-  button->setDefault(true);
-  button->setFont(font);
-  button->setText(tr("&Define Auxiliary\nMetadata Fields"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editData()));
+  feed_castorder_box=new QComboBox(this,"feed_castorder_box");
+  feed_castorder_box->setGeometry(155,478,100,19);
+  feed_castorder_box->insertItem(tr("Descending"));
+  feed_castorder_box->insertItem(tr("Ascending"));
+  feed_castorder_label=new QLabel(feed_castorder_box,tr("Episode Sort Order:"),
+				  this,"feed_castorder_label");
+  feed_castorder_label->setGeometry(20,478,130,19);
+  feed_castorder_label->setFont(font);
+  feed_castorder_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
+  //
+  // Media Link Mode
+  //
+  feed_media_link_mode_box=new QComboBox(this,"feed_media_link_mode_box");
+  feed_media_link_mode_box->setGeometry(155,500,100,19);
+  feed_media_link_mode_box->insertItem(tr("None"));
+  feed_media_link_mode_box->insertItem(tr("Direct"));
+  feed_media_link_mode_box->insertItem(tr("Counted"));
+  feed_media_link_mode_label=new QLabel(feed_media_link_mode_box,
+					tr("Media Link Mode:"),
+					this,"feed_media_link_mode_label");
+  feed_media_link_mode_label->setGeometry(20,500,130,19);
+  feed_media_link_mode_label->setFont(font);
+  feed_media_link_mode_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+
+  //
+  // Feed Redirection
+  //
+  feed_redirect_check=new QCheckBox(this,"feed_redirect_check");
+  feed_redirect_check->setGeometry(20,532,15,15);
+  QLabel *label=new QLabel(feed_redirect_check,tr("Enable Feed Redirection"),
+			     this,"feed_redirect_label");
+  label->setGeometry(40,532,200,19);
+  label->setFont(font);
+  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+
+  feed_redirect_edit=new QLineEdit(this,"feed_redirect_edit");
+  feed_redirect_edit->setGeometry(85,552,405,20);
+  feed_redirect_label=new QLabel(feed_redirect_edit,tr("URL:"),
+			     this,"feed_redirect_label");
+  feed_redirect_label->setGeometry(40,552,40,19);
+  feed_redirect_label->setFont(font);
+  feed_redirect_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
   //
   // Header XML
@@ -367,7 +419,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     new QTextEdit(this,"feed_header_xml_edit");
   feed_header_xml_edit->
     setGeometry(615,10,365,76);
-  QLabel *feed_header_xml_label=
+  feed_header_xml_label=
     new QLabel(feed_header_xml_edit,tr("Header XML:"),this,
 	       "feed_header_xml_label");
   feed_header_xml_label->setGeometry(520,10,90,19);
@@ -382,7 +434,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     new QTextEdit(this,"feed_channel_xml_edit");
   feed_channel_xml_edit->
     setGeometry(615,88,365,176);
-  QLabel *feed_channel_xml_label=
+  feed_channel_xml_label=
     new QLabel(feed_channel_xml_edit,tr("Channel XML:"),this,
 	       "feed_channel_xml_label");
   feed_channel_xml_label->setGeometry(520,88,90,19);
@@ -397,7 +449,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     new QTextEdit(this,"feed_item_xml_edit");
   feed_item_xml_edit->
     setGeometry(615,270,365,176);
-  QLabel *feed_item_xml_label=
+  feed_item_xml_label=
     new QLabel(feed_item_xml_edit,tr("Item XML:"),this,
 	       "feed_item_xml_label");
   feed_item_xml_label->setGeometry(520,270,90,19);
@@ -405,6 +457,16 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_item_xml_label->
     setAlignment(AlignRight|AlignVCenter|ShowPrefix);
 
+  //
+  //  Metadata Button
+  //
+  feed_metadata_button=new QPushButton(this,"feed_metadata_button");
+  feed_metadata_button->setGeometry(615,460,150,50);
+  feed_metadata_button->setDefault(true);
+  feed_metadata_button->setFont(font);
+  feed_metadata_button->setText(tr("&Define Auxiliary\nMetadata Fields"));
+  connect(feed_metadata_button,SIGNAL(clicked()),this,SLOT(editData()));
+
   //
   //  Ok Button
   //
@@ -437,6 +499,7 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
   feed_channel_description_edit->setText(feed_feed->channelDescription());
   feed_channel_language_edit->setText(feed_feed->channelLanguage());
   feed_base_url_edit->setText(feed_feed->baseUrl());
+  feed_base_preamble_edit->setText(feed_feed->basePreamble());
   feed_purge_url_edit->setText(feed_feed->purgeUrl());
   feed_purge_username_edit->setText(feed_feed->purgeUsername());
   feed_purge_password_edit->setText(feed_feed->purgePassword());
@@ -460,15 +523,21 @@ EditFeed::EditFeed(const QString &feed,QWidget *parent,const char *name)
     feed_normalize_box->setChecked(true);
     feed_normalize_spin->setValue(feed_feed->normalizeLevel()/1000);
   }
+  feed_castorder_box->setCurrentItem(feed_feed->castOrder());
+  feed_media_link_mode_box->setCurrentItem((int)feed_feed->mediaLinkMode());
+  feed_redirect_edit->setText(feed_feed->redirectPath());
+  feed_redirect_check->setChecked(!feed_redirect_edit->text().isEmpty());
   normalizeCheckData(feed_normalize_box->isChecked());
 
-  purgeUrlChangedData(feed_purge_url_edit->text());
+  RedirectChanged(feed_redirect_check->isChecked());
+  connect(feed_redirect_check,SIGNAL(toggled(bool)),
+	  this,SLOT(redirectToggledData(bool)));
 }
 
 
 QSize EditFeed::sizeHint() const
 {
-  return QSize(1000,525);
+  return QSize(1000,591);
 } 
 
 
@@ -482,7 +551,8 @@ void EditFeed::purgeUrlChangedData(const QString &str)
 {
   QUrl url(str);
   QString protocol=url.protocol();
-  if((protocol=="ftp")||(protocol=="smb")) {
+  if(((protocol=="ftp")||(protocol=="smb"))&&
+     (!feed_redirect_check->isChecked())) {
     feed_purge_username_label->setEnabled(true);
     feed_purge_username_edit->setEnabled(true);
   }
@@ -497,9 +567,11 @@ void EditFeed::purgeUrlChangedData(const QString &str)
 void EditFeed::purgeUsernameChangedData(const QString &username)
 {
   feed_purge_password_label->
-    setDisabled(username.isEmpty()||feed_purge_url_edit->text().isEmpty());
+    setDisabled(username.isEmpty()||feed_purge_url_edit->text().isEmpty()||
+		feed_redirect_check->isChecked());
   feed_purge_password_edit->
-    setDisabled(username.isEmpty()||feed_purge_url_edit->text().isEmpty());
+    setDisabled(username.isEmpty()||feed_purge_url_edit->text().isEmpty()||
+		feed_redirect_check->isChecked());
 }
 
 
@@ -519,7 +591,7 @@ void EditFeed::normalizeCheckData(bool state)
 {
   feed_normalize_label->setEnabled(state);
   feed_normalize_spin->setEnabled(state);
-  feed_normalize_unit->setEnabled(state);
+  feed_normalize_unit_label->setEnabled(state);
 }
 
 
@@ -531,6 +603,23 @@ void EditFeed::editData()
 }
 
 
+void EditFeed::redirectToggledData(bool state)
+{
+  if(state) {
+    switch(QMessageBox::warning(this,tr("Edit Feed - Redirect"),
+				tr("Enabling feed redirection will cause clients subscribed to\nthis feed to be PERMANENTLY redirected to the\nspecified URL.\n\nDo you still want to enable redireciton?"),QMessageBox::Yes,QMessageBox::No)) {
+      case QMessageBox::Yes:
+	break;
+	
+      default:
+	feed_redirect_check->setChecked(false);
+	return;
+    }
+  }
+  RedirectChanged(state);
+}
+
+
 void EditFeed::okData()
 {
   feed_feed->setChannelTitle(feed_channel_title_edit->text());
@@ -541,6 +630,7 @@ void EditFeed::okData()
   feed_feed->setChannelDescription(feed_channel_description_edit->text());
   feed_feed->setChannelLanguage(feed_channel_language_edit->text());
   feed_feed->setBaseUrl(feed_base_url_edit->text());
+  feed_feed->setBasePreamble(feed_base_preamble_edit->text());
   feed_feed->setPurgeUrl(feed_purge_url_edit->text());
   feed_feed->setPurgeUsername(feed_purge_username_edit->text());
   feed_feed->setPurgePassword(feed_purge_password_edit->text());
@@ -564,6 +654,15 @@ void EditFeed::okData()
   else {
     feed_feed->setNormalizeLevel(1);
   }
+  feed_feed->setCastOrder(feed_castorder_box->currentItem());
+  feed_feed->setMediaLinkMode((RDFeed::MediaLinkMode)feed_media_link_mode_box->
+			      currentItem());
+  if(feed_redirect_check->isChecked()) {
+    feed_feed->setRedirectPath(feed_redirect_edit->text());
+  }
+  else {
+    feed_feed->setRedirectPath("");
+  }
 
   done(0);
 }
@@ -585,3 +684,65 @@ void EditFeed::paintEvent(QPaintEvent *e)
   p->lineTo(10,50);
   delete p;
 }
+
+
+void EditFeed::RedirectChanged(bool state)
+{
+  feed_redirect_label->setEnabled(state);
+  feed_redirect_edit->setEnabled(state);
+  feed_channel_title_edit->setDisabled(state);
+  feed_channel_description_edit->setDisabled(state);
+  feed_channel_category_edit->setDisabled(state);
+  feed_channel_link_edit->setDisabled(state);
+  feed_channel_copyright_edit->setDisabled(state);
+  feed_channel_webmaster_edit->setDisabled(state);
+  feed_channel_language_edit->setDisabled(state);
+  feed_base_url_edit->setDisabled(state);
+  feed_purge_url_edit->setDisabled(state);
+  feed_purge_username_label->setDisabled(state);
+  feed_purge_username_edit->setDisabled(state);
+  feed_purge_password_label->setDisabled(state);
+  feed_purge_password_edit->setDisabled(state);
+  feed_header_xml_edit->setDisabled(state);
+  feed_channel_xml_edit->setDisabled(state);
+  feed_item_xml_edit->setDisabled(state);
+  feed_max_shelf_life_spin->setDisabled(state);
+  feed_autopost_box->setDisabled(state);
+  feed_keep_metadata_box->setDisabled(state);
+  feed_format_edit->setDisabled(state);
+  feed_normalize_box->setDisabled(state);
+  feed_extension_edit->setDisabled(state);
+  feed_castorder_box->setDisabled(state);
+  feed_format_button->setDisabled(state);
+  feed_metadata_button->setDisabled(state);
+  feed_channel_title_label->setDisabled(state);
+  feed_channel_category_label->setDisabled(state);
+  feed_channel_link_label->setDisabled(state);
+  feed_channel_copyright_label->setDisabled(state);
+  feed_channel_webmaster_label->setDisabled(state);
+  feed_channel_language_label->setDisabled(state);
+  feed_channel_description_label->setDisabled(state);
+  feed_base_url_label->setDisabled(state);
+  feed_base_preamble_label->setDisabled(state);
+  feed_purge_url_label->setDisabled(state);
+  feed_max_shelf_life_label->setDisabled(state);
+  feed_max_shelf_life_unit_label->setDisabled(state);
+  feed_autopost_label->setDisabled(state);
+  feed_keep_metadata_label->setDisabled(state);
+  feed_format_label->setDisabled(state);
+  feed_normalize_check_label->setDisabled(state);
+  feed_normalize_unit_label->setDisabled(state);
+  feed_castorder_label->setDisabled(state);
+  feed_extension_label->setDisabled(state);
+  feed_channel_section_label->setDisabled(state);
+  feed_header_xml_label->setDisabled(state);
+  feed_channel_xml_label->setDisabled(state);
+  feed_item_xml_label->setDisabled(state);
+  feed_normalize_label->setDisabled(state||(!feed_normalize_box->isChecked()));
+  feed_normalize_spin->setDisabled(state||(!feed_normalize_box->isChecked()));
+  feed_normalize_unit_label->
+    setDisabled(state||(!feed_normalize_box->isChecked()));
+  feed_media_link_mode_box->setDisabled(state);
+  feed_media_link_mode_label->setDisabled(state);
+  purgeUrlChangedData(feed_purge_url_edit->text());
+}
