@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_rdairplay.cpp,v 1.43 2007/12/05 20:17:32 fredg Exp $
+//      $Id: edit_rdairplay.cpp,v 1.45.2.4 2009/03/30 19:02:52 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,11 +32,13 @@
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
 #include <qpainter.h>
+#include <qfiledialog.h>
 
 #include <rd.h>
 #include <rddb.h>
 #include <rdtextvalidator.h>
 #include <rdlist_logs.h>
+#include <globals.h>
 
 #include <edit_rdairplay.h>
 #include <edit_now_next.h>
@@ -373,7 +375,6 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   air_default_transtype_box->insertItem(tr("Play"));
   air_default_transtype_box->insertItem(tr("Segue"));
   air_default_transtype_box->insertItem(tr("Stop"));
-  air_default_transtype_box->insertItem(tr("Overlap"));
 
   //
   // Default Service
@@ -514,12 +515,38 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   label->setGeometry(830,466,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
+  //
+  // Show Extra Counters/Buttons
+  //
+  air_show_counters_box=new QCheckBox(this,"air_show_counters_box");
+  air_show_counters_box->setGeometry(810,488,15,15);
+  label=new QLabel(air_show_counters_box,tr("Show Extra Buttons/Counters"),
+		   this,"air_show_counters_label");
+  label->setGeometry(830,488,170,15);
+  label->setAlignment(AlignLeft|AlignVCenter);
+
+  //
+  // Audition Preroll
+  //
+  air_audition_preroll_spin=new QSpinBox(this,"air_audition_preroll_spin");
+  air_audition_preroll_spin->setGeometry(895,508,45,20);
+  air_audition_preroll_spin->setRange(1,60);
+  air_audition_preroll_label=new QLabel(air_audition_preroll_spin,
+					tr("Audition Preroll:"),
+					this,"air_audition_preroll_label");
+  air_audition_preroll_label->setGeometry(800,510,90,15);
+  air_audition_preroll_label->setAlignment(AlignRight|AlignVCenter);
+  air_audition_preroll_unit=
+    new QLabel(tr("secs"),this,"air_audition_preroll_unit");
+  air_audition_preroll_unit->setGeometry(945,510,100,15);
+  air_audition_preroll_unit->setAlignment(AlignLeft|AlignVCenter);
+
   //
   // Space Bar Action
   //
   air_bar_group=new QButtonGroup(1,Qt::Vertical,tr("Space Bar Action"),
 				 this,"air_bar_group");
-  air_bar_group->setGeometry(805,488,sizeHint().width()-815,55);
+  air_bar_group->setGeometry(805,532,sizeHint().width()-815,55);
   QRadioButton *rbutton=
     new QRadioButton(tr("None"),air_bar_group,"none_button");
   rbutton=new QRadioButton(tr("Start Next"),air_bar_group,"start_next_button");
@@ -528,7 +555,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   // Now & Next Button
   //
   QPushButton *button=new QPushButton(this,"nownext_button");
-  button->setGeometry(815,559,180,50);
+  button->setGeometry(815,603,180,50);
   button->setFont(small_font);
   button->setText(tr("Configure Now && Next\nParameters"));
   connect(button,SIGNAL(clicked()),this,SLOT(nownextData()));
@@ -611,6 +638,26 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   air_startlog_button->setText(tr("&Select"));
   connect(air_startlog_button,SIGNAL(clicked()),this,SLOT(selectData()));
 
+  //
+  // Display Settings Section
+  //
+  label=new QLabel(tr("Display Settings"),this,"globals_label");
+  label->setFont(big_font);
+  label->setGeometry(435,411,200,16);
+
+  //
+  // Skin Path
+  //
+  air_skin_edit=new QLineEdit(this,"air_skin_edit");
+  air_skin_edit->setGeometry(555,433,180,20);
+  label=new QLabel(air_skin_edit,tr("Background Image:"),
+		   this,"air_skin_label");
+  label->setGeometry(435,433,115,20);
+  label->setAlignment(AlignRight|AlignVCenter);
+  button=new QPushButton(tr("Select"),this,"skin_select_button");
+  button->setGeometry(745,430,50,25);
+  connect(button,SIGNAL(clicked()),this,SLOT(selectSkinData()));
+
   //
   //  Ok Button
   //
@@ -683,6 +730,8 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   air_panel_pause_box->setChecked(air_conf->panelPauseEnabled());
   air_label_template_edit->setText(air_conf->buttonLabelTemplate());
   air_pause_box->setChecked(air_conf->pauseEnabled());
+  air_show_counters_box->setChecked(air_conf->showCounters());
+  air_audition_preroll_spin->setValue(air_conf->auditionPreroll()/1000);
   for(int i=0;i<10;i++) {
     air_start_rml_edit[i]->setText(air_conf->startRml(i));
     air_stop_rml_edit[i]->setText(air_conf->stopRml(i));
@@ -695,6 +744,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   air_startmode_box->setCurrentItem((int)air_startmode[air_logmachine]);
   air_startlog_edit->setText(air_startlog[air_logmachine]);
   air_autorestart_box->setChecked(air_autorestart[air_logmachine]);
+  air_skin_edit->setText(air_conf->skinPath());
   startModeChangedData(air_startmode[air_logmachine]);
 }
 
@@ -756,7 +806,8 @@ void EditRDAirPlay::selectData()
 {
   QString logname=air_startlog_edit->text();
 
-  RDListLogs *ll=new RDListLogs(&logname,air_conf->station(),this);
+  RDListLogs *ll=new RDListLogs(&logname,air_conf->station(),this,
+                                "log",admin_user);
   if(ll->exec()==0) {
     air_startlog_edit->setText(logname);
   }
@@ -772,6 +823,17 @@ void EditRDAirPlay::nownextData()
 }
 
 
+void EditRDAirPlay::selectSkinData()
+{
+  QString filename=air_skin_edit->text();
+  filename=QFileDialog::getOpenFileName(filename,RD_IMAGE_FILE_FILTER,this,"",
+					tr("Select Image File"));
+  if(!filename.isNull()) {
+    air_skin_edit->setText(filename);
+  }
+}
+
+
 void EditRDAirPlay::okData()
 {
   bool ok=false;
@@ -820,6 +882,8 @@ void EditRDAirPlay::okData()
   air_conf->setPanelPauseEnabled(air_panel_pause_box->isChecked());
   air_conf->setButtonLabelTemplate(air_label_template_edit->text());
   air_conf->setPauseEnabled(air_pause_box->isChecked());
+  air_conf->setShowCounters(air_show_counters_box->isChecked());
+  air_conf->setAuditionPreroll(air_audition_preroll_spin->value()*1000);
   if(air_exitpasswd_changed) {
     air_conf->setExitPassword(air_exitpasswd_edit->text());
   }
@@ -832,6 +896,7 @@ void EditRDAirPlay::okData()
     air_conf->setLogName(i,air_startlog[i]);
     air_conf->setAutoRestart(i,air_autorestart[i]);
   }
+  air_conf->setSkinPath(air_skin_edit->text());
   done(0);
 }
 
