@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_event.cpp,v 1.43.2.1 2009/03/30 19:02:52 cvs Exp $
+//      $Id: edit_event.cpp,v 1.43.2.4 2010/02/08 23:50:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,7 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qpainter.h>
+#include <qmessagebox.h>
 
 #include <rdconf.h>
 
@@ -75,8 +76,10 @@ EditEvent::EditEvent(LogPlay *log,QWidget *parent,const char *name)
   //
   // Start Time
   //
-  edit_time_edit=new QTimeEdit(this,"edit_time_edit");
-  edit_time_edit->setGeometry(90,19,80,20);
+  edit_time_edit=new RDTimeEdit(this,"edit_time_edit");
+  edit_time_edit->setGeometry(85,19,85,20);
+  edit_time_edit->setDisplay(RDTimeEdit::Hours|RDTimeEdit::Minutes|
+			     RDTimeEdit::Seconds|RDTimeEdit::Tenths);
   connect(edit_time_edit,SIGNAL(valueChanged(const QTime &)),
 	  this,SLOT(timeChangedData(const QTime &)));
 
@@ -100,9 +103,10 @@ EditEvent::EditEvent(LogPlay *log,QWidget *parent,const char *name)
   radio_button=new QRadioButton(tr("Wait up to"),edit_grace_group);
   edit_grace_group->insert(radio_button);
   radio_button->setFont(radio_font);
-  edit_grace_edit=new QTimeEdit(this,"edit_grace_edit");
-  edit_grace_edit->setGeometry(543,31,60,20);
-  edit_grace_edit->setDisplay(QTimeEdit::Minutes|QTimeEdit::Seconds);
+  edit_grace_edit=new RDTimeEdit(this,"edit_grace_edit");
+  edit_grace_edit->setGeometry(538,31,65,20);
+  edit_grace_edit->setDisplay(RDTimeEdit::Minutes|RDTimeEdit::Seconds|
+			      RDTimeEdit::Tenths);
   connect(edit_timetype_box,SIGNAL(toggled(bool)),
 	  this,SLOT(timeToggledData(bool)));
   connect(edit_grace_group,SIGNAL(clicked(int)),
@@ -118,7 +122,7 @@ EditEvent::EditEvent(LogPlay *log,QWidget *parent,const char *name)
   edit_transtype_box->insertItem(tr("Stop"));  
   edit_time_label=new QLabel(edit_transtype_box,tr("Start Transition Type:"),
 			     this,"edit_transtype_label");
-  edit_time_label->setGeometry(150,68,330,26);
+  edit_time_label->setGeometry(190,68,290,26);
   edit_time_label->setFont(label_font);
   edit_time_label->setAlignment(AlignRight|AlignVCenter);
 
@@ -127,7 +131,7 @@ EditEvent::EditEvent(LogPlay *log,QWidget *parent,const char *name)
   edit_overlap_box->setGeometry(30,72,15,15);
   edit_overlap_label=new QLabel(edit_overlap_box,tr("No Fade at Segue Out"),
 				this,"edit_overlap_label");
-  edit_overlap_label->setGeometry(50,68,270,26);
+  edit_overlap_label->setGeometry(50,68,130,26);
   edit_overlap_label->setFont(button_font);
   edit_overlap_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
   
@@ -449,7 +453,8 @@ void EditEvent::timeChangedData(const QTime &time)
     str=QString(tr("Transition If Previous Cart Ends Before"));
     edit_time_label->
       setText(QString().sprintf("%s %s:",(const char *)str,
-		  (const char *)edit_time_edit->time().toString("hh:mm:ss")));
+				(const char *)edit_time_edit->time().
+				toString("hh:mm:ss.zzz").left(10)));
   }
 }
 
@@ -465,7 +470,8 @@ void EditEvent::timeToggledData(bool state)
     str=QString(tr("Transition If Previous Cart Ends Before"));
     edit_time_label->
       setText(QString().sprintf("%s %s:",(const char *)str,
-	     (const char *)edit_time_edit->time().toString("hh:mm:ss")));
+	     (const char *)edit_time_edit->time().
+				toString("hh:mm:ss.zzz").left(10)));
   }
   else {
     edit_grace_edit->setDisabled(true);
@@ -650,6 +656,12 @@ void EditEvent::auditionTimerData()
 
 void EditEvent::okData()
 {
+  if(edit_timetype_box->isChecked()&&
+     edit_log->exists(edit_time_edit->time(),edit_line)) {
+    QMessageBox::warning(this,tr("Duplicate Start Time"),
+	       	 tr("An event is already scheduled with this start time!"));
+    return;
+  }
   if(edit_play_deck->state()==RDPlayDeck::Playing) {
     edit_play_deck->stop();
   }
@@ -1001,11 +1013,10 @@ void EditEvent::keyPressEvent(QKeyEvent *e)
   switch(e->key()) {
       case Qt::Key_Shift:
         edit_shift_pressed=true;
-	QWidget::keyPressEvent(e);
   	break;
 
       default:
-	QWidget::keyPressEvent(e);
+	e->ignore();
 	break;
   }
 }
