@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_log.cpp,v 1.100.2.3 2009/03/26 20:27:57 cvs Exp $
+//      $Id: list_log.cpp,v 1.100.2.4 2010/02/08 23:50:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -56,7 +56,6 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_op_mode=RDAirPlayConf::LiveAssist;
   list_action_mode=RDAirPlayConf::Normal;
   list_time_mode=RDAirPlayConf::TwentyFourHour;
-  list_time_format="hh:mm:ss";
   list_scroll=true;
   list_pause_allowed=allow_pause;
   list_playbutton_mode=ListLog::ButtonDisabled;
@@ -554,18 +553,6 @@ void ListLog::setTimeMode(RDAirPlayConf::TimeMode mode)
   if(mode==list_time_mode) {
     return;
   }
-  switch(mode) {
-      case RDAirPlayConf::TwentyFourHour:
-	list_time_format="hh:mm:ss";
-	break;
-
-      case RDAirPlayConf::TwelveHour:
-	list_time_format="h:mm:ss ap";
-	break;
-
-      default:
-	break;
-  }
   list_time_mode=mode;
   UpdateTimes();
   RefreshList();
@@ -981,7 +968,6 @@ void ListLog::selectionChangedData()
 
       case RDLogLine::Playing:
 	SetPlaybuttonMode(ListLog::ButtonStop);
-	//list_modify_button->setDisabled(true);
 	list_modify_button->setEnabled(true);
 	list_next_button->setDisabled(true);
 	break;
@@ -1113,10 +1099,10 @@ void ListLog::RefreshItem(RDListViewItem *l,int line)
   }
   switch(log_line->timeType()) {
       case RDLogLine::Hard:
-	l->setText(1,QString("T")+log_line->startTime(RDLogLine::Logged).
-		   toString(list_time_format));
-	l->setText(8,QString("T")+log_line->startTime(RDLogLine::Logged).
-		   toString(list_time_format));
+	l->setText(1,QString("T")+
+		   TimeString(log_line->startTime(RDLogLine::Logged)));
+	l->setText(8,QString("T")+
+		   TimeString(log_line->startTime(RDLogLine::Logged)));
 	for(int i=0;i<list_log_list->columns();i++) {
 	  l->setTextColor(i,LOG_HARDTIME_TEXT_COLOR,QFont::Bold);
 	}
@@ -1124,8 +1110,7 @@ void ListLog::RefreshItem(RDListViewItem *l,int line)
 	break;
       default:
 	if(!log_line->startTime(RDLogLine::Logged).isNull()) {
-	  l->setText(8,log_line->startTime(RDLogLine::Logged).
-		     toString(list_time_format));
+	  l->setText(8,TimeString(log_line->startTime(RDLogLine::Logged)));
 	}
 	else {
 	  l->setText(8,"");
@@ -1354,15 +1339,14 @@ void ListLog::UpdateTimes(int removed_line,int num_lines)
 	  case RDLogLine::Paused:
 	    switch(logline->timeType()) {
 		case RDLogLine::Hard:
-		  next->setText(1,QString(tr("T"))+logline->
-				startTime(RDLogLine::Logged).
-				toString(list_time_format));
+		  next->setText(1,QString(tr("T"))+
+			  TimeString(logline->startTime(RDLogLine::Logged)));
 		  break;
 		  
 		default:
 		  if(!logline->startTime(RDLogLine::Predicted).isNull()) {
-		    next->setText(1,logline->startTime(RDLogLine::Predicted).
-				  toString(list_time_format));
+		    next->setText(1,
+			TimeString(logline->startTime(RDLogLine::Predicted)));
 		  }
 		  else {
 		    next->setText(1,"");
@@ -1370,16 +1354,9 @@ void ListLog::UpdateTimes(int removed_line,int num_lines)
 		  break;
 	    }
 	    break;
-	    
-/*
-	  case RDLogLine::NoCart:
-	    next->setText(1,"");
-	    break;
-*/
 
 	  default:
-	    next->setText(1,logline->startTime(RDLogLine::Actual).
-		      toString(list_time_format));
+	    next->setText(1,TimeString(logline->startTime(RDLogLine::Actual)));
 	    break;
       }
       next=(RDListViewItem *)next->nextSibling();
@@ -1499,3 +1476,21 @@ void ListLog::SetPlaybuttonMode(ListLog::PlayButtonMode mode)
   }
   list_playbutton_mode=mode;
 }
+
+
+QString ListLog::TimeString(const QTime &time) const
+{
+  QString ret;
+  switch(list_time_mode) {
+  case RDAirPlayConf::TwelveHour:
+    ret=time.toString("h:mm:ss.zzz");
+    ret=ret.left(ret.length()-2);
+    ret+=(" "+time.toString("ap"));
+    break;
+
+  case RDAirPlayConf::TwentyFourHour:
+    ret=time.toString("hh:mm:ss.zzz").left(10);
+    break;
+  }
+  return ret;
+}
