@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: audio_cart.cpp,v 1.50 2007/12/29 21:05:36 fredg Exp $
+//      $Id: audio_cart.cpp,v 1.50.2.1 2010/02/09 21:43:53 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -536,6 +536,10 @@ void AudioCart::importCutData()
 					  &wavedata,cut_clipboard,
 					  rdstation_conf,&import_active,
 					  lib_config);
+  import->enableAutotrim(rdlibrary_conf->defaultTrimState());
+  import->setAutotrimLevel(rdlibrary_conf->trimThreshold());
+  import->enableNormalization(rdlibrary_conf->ripperLevel()!=0);
+  import->setNormalizationLevel(rdlibrary_conf->ripperLevel());
   if(import->exec(true,true)==0) {
     if(rdcart_controls->title_edit->text().isEmpty()||
        (rdcart_controls->title_edit->text()==tr("[new cart]"))) {
