@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_macro.cpp,v 1.8 2007/02/14 21:55:07 fredg Exp $
+//      $Id: edit_macro.cpp,v 1.9 2007/09/14 14:06:55 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,8 +24,6 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qsqldatabase.h>
-#include <rconf.h>
-#include <math.h>
 
 #include <rdtextvalidator.h>
 
