@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: record_cut.cpp,v 1.86 2008/08/04 19:05:35 fredg Exp $
+//      $Id: record_cut.cpp,v 1.86.2.1 2010/01/20 22:22:50 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -283,7 +283,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   cut_starttime_disable_button->setGeometry(57,345,100,20);
   button_group->insert(cut_starttime_disable_button,false);
 
-  cut_starttime_edit=new QTimeEdit(this,"cut_starttime_edit");
+  cut_starttime_edit=new RDTimeEdit(this,"cut_starttime_edit");
   cut_starttime_edit->setGeometry(222,324,90,19);
   cut_starttime_label=new QLabel(cut_starttime_edit,tr("&Start Time"),this,
 				       "cut_starttime_label");
@@ -291,7 +291,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   cut_starttime_label->setFont(small_font);
   cut_starttime_label->setAlignment(AlignRight|ShowPrefix);
 
-  cut_endtime_edit=new QTimeEdit(this,"cut_endtime_edit");
+  cut_endtime_edit=new RDTimeEdit(this,"cut_endtime_edit");
   cut_endtime_edit->setGeometry(222,344,90,19);
   cut_endtime_label=new QLabel(cut_endtime_edit,tr("End Time"),this,
 				       "cut_endtime_label");
@@ -553,6 +553,8 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
   //
   cut_description_edit->setReadOnly(!allow_modification);
   cut_outcue_edit->setReadOnly(!allow_modification);
+  cut_starttime_edit->setReadOnly(!allow_modification);
+  cut_endtime_edit->setReadOnly(!allow_modification);
   if(!allow_modification) {
     cut_weight_box->setRange(cut_weight_box->value(),cut_weight_box->value());
     if(cut_startdatetime_enable_button->isChecked()) {
@@ -570,10 +572,6 @@ RecordCut::RecordCut(RDCart *cart,QString cut,QWidget *parent,const char *name)
       cut_enddatetime_edit->timeEdit()->
 	setRange(cut_enddatetime_edit->timeEdit()->time(),
 		 cut_enddatetime_edit->timeEdit()->time());
-      cut_starttime_edit->
-	setRange(cut_starttime_edit->time(),cut_starttime_edit->time());
-      cut_endtime_edit->
-	setRange(cut_endtime_edit->time(),cut_endtime_edit->time());
     }
   }
   rec_evergreen_box->setEnabled(allow_modification);
