@@ -477,6 +477,14 @@ group for the specified service!</source>
         <source>No Fade on Segue Out</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Duplicate Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>An event is already scheduled with this start time!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMarker</name>
