@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: add_clock.cpp,v 1.9.2.1 2008-10-24 12:58:16 fredg Exp $
+//      $Id: add_clock.cpp,v 1.9.2.2 2009/06/29 14:20:48 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -88,6 +88,11 @@ AddClock::AddClock(QString *logname,QWidget *parent,const char *name)
   validator->addBannedChar('-');
   validator->addBannedChar('_');
   validator->addBannedChar('/');
+  validator->addBannedChar('+');
+  validator->addBannedChar('=');
+  validator->addBannedChar('~');
+  validator->addBannedChar('?');
+  validator->addBannedChar('|');
 
   //
   // Clock Name
