@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_clock.cpp,v 1.22.2.2 2008-11-30 00:33:00 fredg Exp $
+//      $Id: edit_clock.cpp,v 1.22.2.3 2010/02/08 23:50:14 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -598,10 +598,11 @@ void EditClock::RefreshList(int select_line)
   for(int i=edit_clock->size()-1;i>=0;i--) {
     if((eventline=edit_clock->eventLine(i))!=NULL) {
       item=new RDListViewItem(edit_clocks_list);
-      item->setText(0,eventline->startTime().toString("mm:ss"));
+      item->setText(0,eventline->startTime().toString("mm:ss.zzz").left(7));
       item->setText(1,eventline->startTime().
-		    addMSecs(eventline->length()).toString("mm:ss"));
-      item->setText(3,RDGetTimeLength(eventline->length(),false,false));
+		    addMSecs(eventline->length()).toString("mm:ss.zzz").
+		    left(7));
+      item->setText(3,RDGetTimeLength(eventline->length(),false,true));
       item->setText(2,QString().sprintf("%s [%s]",
 		    (const char *)eventline->name(),
 		    (const char *)eventline->properties()));
