@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_grid.cpp,v 1.10 2007/10/04 20:53:39 dmills Exp $
+//      $Id: edit_grid.cpp,v 1.10.2.2 2009/06/29 13:32:55 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -48,7 +48,7 @@ EditGrid::EditGrid(QString servicename,QWidget *parent,const char *name)
   QString sql;
   QString str;
 
-  sql=QString(tr("Edit Grid:"));
+  str=QString(tr("Edit Grid:"));
   setCaption(QString().sprintf("%s %s",(const char *)str,
 			       (const char *)servicename));
   edit_servicename=servicename;
@@ -119,6 +119,8 @@ EditGrid::EditGrid(QString servicename,QWidget *parent,const char *name)
   connect(edit_right_menu,SIGNAL(aboutToShow()),this,SLOT(aboutToShowData()));
   edit_right_menu->
     insertItem(tr("Edit Clock"),this,SLOT(editClockData()),0,0);
+  edit_right_menu->
+    insertItem(tr("Clear Hour"),this,SLOT(clearHourData()),0,1);
 
   //
   //  Close Button
@@ -184,7 +186,6 @@ void EditGrid::rightHourButtonData(int id,const QPoint &pt)
 		geometry().x()+pt.x()+2,
 		edit_hour_button[dayofweek-1][hour]->geometry().y()+
 		geometry().y()+pt.y(),
-//		header()->geometry().height()+2,
 		edit_right_menu->sizeHint().width(),
 		edit_right_menu->sizeHint().height());
   edit_right_menu->exec();
@@ -196,6 +197,7 @@ void EditGrid::aboutToShowData()
   int dayofweek=edit_rightclick_id/24+1;
   int hour=edit_rightclick_id-24*(dayofweek-1);
   edit_right_menu->setItemEnabled(0,!GetClock(dayofweek,hour).isEmpty());
+  edit_right_menu->setItemEnabled(1,!GetClock(dayofweek,hour).isEmpty());
 }
 
 
@@ -219,6 +221,20 @@ void EditGrid::editClockData()
 }
 
 
+void EditGrid::clearHourData()
+{
+  int dayofweek=edit_rightclick_id/24+1;
+  int hour=edit_rightclick_id-24*(dayofweek-1);
+  QString sql=QString().sprintf("update SERVICES set CLOCK%d=\"\"\
+                                 where NAME=\"%s\"",
+				edit_rightclick_id,
+				(const char *)edit_servicename);
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  delete q;
+  LabelButton(dayofweek,hour,"");
+}
+
+
 void EditGrid::closeData()
 {
   done(-1);
