@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: generate_log.cpp,v 1.26 2007/05/26 20:58:55 stgabriel Exp $
+//      $Id: generate_log.cpp,v 1.32.2.1 2009/02/12 14:21:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,25 +20,28 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <stdlib.h>
+
 #include <qdialog.h>
 #include <qstring.h>
-#include <qsqldatabase.h>
 #include <qdatetimeedit.h>
 #include <qmessagebox.h>
 #include <qfile.h>
 #include <qtimer.h>
 
-#include <rconf.h>
-#include <rdatedialog.h>
+#include <rddb.h>
+#include <rddatedialog.h>
 #include <rdsvc.h>
 #include <rddatedecode.h>
 #include <rdlog.h>
 #include <rd.h>
 #include <rdexception_dialog.h>
 #include <rdtextfile.h>
+#include <rdcreate_log.h>
 
 #include <generate_log.h>
 #include <edit_grid.h>
+#include <globals.h>
 
 //
 // Icons
@@ -51,12 +54,16 @@
 GenerateLog::GenerateLog(QWidget *parent,const char *name,int cmd_switch,QString *cmd_service,QDate *cmd_date)
   : QDialog(parent,name,true)
 {
+  QStringList services_list;
   bool  cmdservicefit=false;
   cmdswitch=cmd_switch;
   cmdservice = cmd_service;
   cmddate = cmd_date;
 
-  setCaption(tr("Generate Log"));
+  QString str1=tr("Generate Log - User: ");
+  setCaption(QString().sprintf("%s%s",(const char *)str1,
+			       (const char *)rdripc->user()));
+
   gen_music_enabled=false;
   gen_traffic_enabled=false;
 
@@ -105,14 +112,24 @@ GenerateLog::GenerateLog(QWidget *parent,const char *name,int cmd_switch,QString
   label->setGeometry(10,10,55,20);
   label->setFont(bold_font);
   label->setAlignment(AlignRight|AlignVCenter);
-  QString sql="select NAME from SERVICES";
-  QSqlQuery *q=new QSqlQuery(sql);
-  while(q->next()) {
-    gen_service_box->insertItem(q->value(0).toString());
-    if (cmdswitch != 0 && *cmdservice == q->value(0).toString())
+
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+    services_list = rduser->services();
+  } else { // RDStation::HostSec
+    QString sql="select NAME from SERVICES";
+    RDSqlQuery *q=new RDSqlQuery(sql);
+    while(q->next()) {
+      services_list.append( q->value(0).toString() );
+    }
+    delete q;
+  }
+  for ( QStringList::Iterator it = services_list.begin(); 
+        it != services_list.end();
+        ++it ) {
+    gen_service_box->insertItem(*it);
+    if (cmdswitch != 0 && *cmdservice == *it)
       cmdservicefit=true;
   }
-  delete q;
 
   //
   // Date
@@ -285,8 +302,8 @@ void GenerateLog::selectDateData()
   QDate date=gen_date_edit->date();
   QDate current_date=QDate::currentDate();
 
-  RDateDialog *datedialog=
-    new RDateDialog(current_date.year(),current_date.year()+1,
+  RDDateDialog *datedialog=
+    new RDDateDialog(current_date.year(),current_date.year()+1,
 		    this,"datedialog");
   if(datedialog->exec(&date)<0) {
     delete datedialog;
@@ -345,19 +362,14 @@ void GenerateLog::createData()
 
 ///////////  Scheduler
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   srand(QTime::currentTime().msec());
 
-  sql=QString().sprintf("create table if not exists `%s_STACK` (\
-      SCHED_STACK_ID int unsigned not null primary key,\
-      CART int unsigned not null,\
-      ARTIST varchar(255),\
-      SCHED_CODES varchar(255),\
-      SCHEDULED_AT datetime default '1000-01-01 00:00:00'\
-        )",(const char*)gen_service_box->currentText().replace(" ","_")); 
 
-  q=new QSqlQuery(sql);
+  sql=RDCreateStackTableSql(gen_service_box->currentText().replace(" ","_")); 
+
+  q=new RDSqlQuery(sql);
   if(!q->isActive()) {
     printf("SQL: %s\n",(const char *)sql);
     printf("SQL Error: %s\n",(const char *)q->lastError().databaseText());
@@ -365,13 +377,13 @@ void GenerateLog::createData()
   }
   delete q;
 
-
-  if (cmdswitch==0)
-  connect(svc,SIGNAL(generationProgress(int)),
-	  gen_progress_dialog,SLOT(setProgress(int)));
-  else
+  if (cmdswitch==0) {
+    connect(svc,SIGNAL(generationProgress(int)),
+	    gen_progress_dialog,SLOT(setProgress(int)));
+  }
+  else {
     printf("Generate Log\n");  
-
+  }
   svc->generateLog(gen_date_edit->date(),
 		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date()),
 		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date().
@@ -383,25 +395,26 @@ void GenerateLog::createData()
   //
   // Generate Exception Report
   //
-  if(cmdswitch==0)
-    {
-  RDLogEvent *event=
-    new RDLogEvent(QString().sprintf("%s_LOG",(const char *)logname));
-  event->load();
-  if((event->validate(&report)==0)&&unused_report.isEmpty()) {
-    QMessageBox::information(this,tr("No Errors"),tr("No exceptions found."));
-  }
-  else {
-    RDTextFile(report+"\n\n"+unused_report);
-  }
-  delete event;
-  UpdateControls();
+  if(cmdswitch==0) {
+    RDLogEvent *event=
+      new RDLogEvent(QString().sprintf("%s_LOG",(const char *)logname));
+    event->load();
+    if((event->validate(&report,gen_date_edit->date())==0)&&
+       unused_report.isEmpty()) {
+      QMessageBox::information(this,tr("No Errors"),tr("No exceptions found."));
+    }
+    else {
+      RDTextFile(report+"\n\n"+unused_report);
+    }
+    delete event;
+    UpdateControls();
   }
   else {
     RDLogEvent *event=
       new RDLogEvent(QString().sprintf("%s_LOG",(const char *)logname));
     event->load();
-    if((event->validate(&report)==0)&&unused_report.isEmpty()) {
+    if((event->validate(&report,gen_date_edit->date())==0)&&
+       unused_report.isEmpty()) {
       printf(tr("No exceptions found."));
     }
     else {
