@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_grids.cpp,v 1.6 2007/10/04 20:53:39 dmills Exp $
+//      $Id: list_grids.cpp,v 1.7.2.1 2009/04/07 13:59:06 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,6 +33,7 @@
 
 #include <list_grids.h>
 #include <edit_grid.h>
+#include <globals.h>
 
 ListGrids::ListGrids(QWidget *parent,const char *name)
   : QDialog(parent,name,true)
@@ -131,9 +132,31 @@ void ListGrids::closeData()
 void ListGrids::RefreshList()
 {
   QListViewItem *prev_item=edit_grids_list->selectedItem();
+  QString sql="select NAME,DESCRIPTION from SERVICES";
+
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec
+      && rduser != NULL) {
+    QStringList services_list;
+    QString sql_where;
+
+    services_list = rduser->services();
+    if(services_list.size()==0) {
+      return;
+    }
+
+    sql_where=" where (";
+    for ( QStringList::Iterator it = services_list.begin(); 
+          it != services_list.end(); ++it ) {
+      sql_where+=QString().sprintf("NAME=\"%s\"||",
+                             (const char *)*it);
+    }
+    sql_where=sql_where.left(sql_where.length()-2);
+    sql_where+=")";
+
+    sql=sql+sql_where;
+  } // else no filter for RDStation::HostSec
 
   edit_grids_list->clear();
-  QString sql="select NAME,DESCRIPTION from SERVICES";
   RDSqlQuery *q=new RDSqlQuery(sql);
   QListViewItem *item=NULL;
   while(q->next()) {
