@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogmanager.h,v 1.11 2007/09/14 14:06:58 fredg Exp $
+//      $Id: rdlogmanager.h,v 1.11.2.1 2010/01/31 22:24:55 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,7 +24,7 @@
 #ifndef RDLOGMANAGER_H
 #define RDLOGMANAGER_H
 
-#include <qdialog.h>
+#include <qwidget.h>
 #include <qsize.h>
 #include <qsizepolicy.h>
 #include <qsqldatabase.h>
@@ -38,7 +38,7 @@
 #include <rdlog_line.h>
 #include <rdconfig.h>
 
-class MainWidget : public QDialog
+class MainWidget : public QWidget
 {
  Q_OBJECT
  public:
