@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpanel.cpp,v 1.19 2008-04-22 18:14:38 fredg Exp $
+//      $Id: rdpanel.cpp,v 1.19.2.1 2009/03/26 23:14:04 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -174,7 +174,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   connect(rdripc,SIGNAL(userChanged()),this,SLOT(userData()));
   connect(rdripc,SIGNAL(rmlReceived(RDMacro *)),
 	  this,SLOT(rmlReceivedData(RDMacro *)));
-  rdripc->connectHost("localhost",RIPCD_TCP_PORT,panel_config->password());
+//  rdripc->connectHost("localhost",RIPCD_TCP_PORT,panel_config->password());
 
   //
   // User
@@ -310,6 +310,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
     panel_stereo_meter->hide();
   }
 
+  rdripc->connectHost("localhost",RIPCD_TCP_PORT,panel_config->password());
+
   //
   // Signal Handlers
   //
@@ -342,6 +344,7 @@ void MainWidget::userData()
   }
   rduser=new RDUser(rdripc->user());
   SetCaption();
+  rdripc->sendOnairFlag();
 }
 
 
