@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: ripcd.cpp,v 1.64.2.4 2008-12-08 16:44:20 fredg Exp $
+//      $Id: ripcd.cpp,v 1.64.2.5 2009/02/10 13:41:35 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -701,6 +701,11 @@ void MainObject::ReadRmlSocket(QSocketDevice *dev,RDMacro::Role role,
       }
     }
     else {
+      LogLine(RDConfig::LogWarning,
+	      QString().sprintf("received malformed rml: \"%s\" from %s:%u",
+				buffer,
+				(const char *)dev->peerAddress().toString(),
+				dev->peerPort()));
       if(echo) {
 	macro.setRole(RDMacro::Reply);
 	macro.setCommand(RDMacro::NN);
